@@ -207,7 +207,7 @@ private slots:
     void OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 callerID);
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
     void OnDisplayStateChanged(bool state); //display state changed notification (true=ON, false=OFF)
-    //void OnProgressSliderClicked(int pos); //progress slider has been clicked (pos=clicked position)
+    void OnProgressSliderClicked(int pos); //progress slider has been clicked (pos=clicked position)
     void OnHalButtonPressed(const QString& value); //button pressed notification (condition) received from HAL (device)
     void OnHeadsetRemoved(); //headset removed notification from Hal device manager received
     void OnPlaybackTokenLost(); //notification from session instance that playback token has been lost
