@@ -39,11 +39,6 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
-    //set up login-related options
-    m_LoginOptionLayout.addWidget(&m_SaveCredentials,0,0,1,-1);
-    m_LoginOptions.setLayout(&m_LoginOptionLayout);
-
-
     //set up bitrate selection value button / selector
 
     m_bitrateList << tr("Low bitrate (96kbps)") << tr("Standard bitrate (160kbps)")
@@ -132,20 +127,19 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
-    m_GridLayout.addWidget(&m_LoginOptions,2,0,1,-1);
-    m_GridLayout.addWidget(&m_HideCoverArt,3,0,1,-1);
+    m_GridLayout.addWidget(&m_HideCoverArt,2,0,1,-1);
 #ifdef Q_WS_MAEMO_5
-    m_GridLayout.addWidget(&m_PreferredBitrateBtn,4,0,1,-1);
-    m_GridLayout.addWidget(&m_UILangBtn,5,0,1,-1);
-    m_GridLayout.addWidget(&m_OrientationBtn,6,0,1,-1);
+    m_GridLayout.addWidget(&m_PreferredBitrateBtn,3,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangBtn,4,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationBtn,5,0,1,-1);
 #else
-    m_GridLayout.addWidget(&m_PreferredBitrateCombo,4,0,1,-1);
-    m_GridLayout.addWidget(&m_UILangCombo,5,0,1,-1);
-    m_GridLayout.addWidget(&m_OrientationCombo,6,0,1,-1);
+    m_GridLayout.addWidget(&m_PreferredBitrateCombo,3,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangCombo,4,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationCombo,5,0,1,-1);
 #endif
-    m_GridLayout.addWidget(&m_PlaylistOptions,7,0,1,-1);
-    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,8,0,1,-1);
-    m_GridLayout.addWidget(&m_ScrobblingOptions,9,0,1,-1);
+    m_GridLayout.addWidget(&m_PlaylistOptions,6,0,1,-1);
+    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,7,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,8,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -188,7 +182,6 @@ void SettingsDialog::setCapsLandscape()
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
     m_SaveSettingsBtn.setText(tr("Save"));
     m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
-    m_SaveCredentials.setText(tr("Remember UserID and password"));
 }
 
 void SettingsDialog::setCapsPortrait()
@@ -216,7 +209,6 @@ void SettingsDialog::setCapsPortrait()
     m_LastFMUserIDCaption.setText(tr("Last.fm username"));
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
     m_SaveSettingsBtn.setText(tr("Save"));
-    m_SaveCredentials.setText(tr("Remember UserID and password"));
     m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
 }
 
@@ -248,16 +240,6 @@ void SettingsDialog::readSettings()
         else
             m_PreBufferNextTrackSelection.setChecked(false);
 
-        m_saveCredentials = m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt();
-        if(m_saveCredentials)
-        { //set save credentials checkbox
-            m_SaveCredentials.setChecked(true);
-        }
-        else
-        {
-            m_SaveCredentials.setChecked(false);
-        }
-
         m_hideCoverart = m_pAppSettings->value("QSpot/HideCoverart",HIDE_COVERART_DEFAULT).toInt();
         if(m_hideCoverart)
         { //set hide coverart checkbox
@@ -365,21 +347,6 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
-        if(m_SaveCredentials.isChecked() && !m_saveCredentials)
-        {
-            m_pAppSettings->setValue("QSpot/SaveCredentials",1);
-           // m_pAppSettings->setValue("QSpot/UserID",m_strUserID);
-            //m_pAppSettings->setValue("QSpot/Password",m_strUserPwd);
-            settingsChanged = true;
-        }
-        else if(!m_SaveCredentials.isChecked() && m_saveCredentials)
-        { //credentials should not be saved, remove any existing values
-            m_pAppSettings->setValue("QSpot/SaveCredentials",0);
-           // m_pAppSettings->setValue("QSpot/UserID","");
-            //m_pAppSettings->setValue("QSpot/Password","");
-            settingsChanged = true;
-        }
-
         if(m_HideCoverArt.isChecked() && !m_hideCoverart)
         {
             m_pAppSettings->setValue("QSpot/HideCoverart",1);
@@ -401,11 +368,6 @@ void SettingsDialog::saveSettings()
         if(selBitrate!=m_prefBitrate)
         {
             m_pAppSettings->setValue("QSpot/PrefBitrate",selBitrate);
-#ifdef Q_WS_MAEMO_5
-            QMaemo5InformationBox::information(this,tr("Please restart QSpot for bitrate change to take effect!"));
-#else
-            Banner::information(this,tr("Please restart QSpot for bitrate change to take effect!"));
-#endif
         }
 
 #ifdef Q_WS_MAEMO_5
