@@ -3,8 +3,9 @@
 #include "error.h"
 #include "link.h"
 
-Spotify::Track::Track( Spotify::Track& track, bool ref ):
+Spotify::Track::Track(sp_session* session, Spotify::Track& track, bool ref ):
         QObject( 0 ),
+        m_session( session ),
         m_hasRef( ref )
 {
     m_track = track.getTrack();
@@ -39,8 +40,9 @@ Spotify::Track::Track( Spotify::Track& track, bool ref ):
     setParent( track.parent() );
 }
 
-Spotify::Track::Track( sp_track* track, bool ref, QObject* parent ):
+Spotify::Track::Track(sp_session* session, sp_track* track, bool ref, QObject* parent ):
         QObject( parent ),
+        m_session( session ),
         m_track( track ),
         m_loaded( false ),
         m_available( false ),
@@ -65,7 +67,7 @@ bool Spotify::Track::load()
     {
        // qDebug()<<"Load track..";
         // Set availability:
-        m_available = sp_track_is_available( m_track );
+        m_available = sp_track_is_available(m_session, m_track );
 
 
         // Set artists:
@@ -131,14 +133,14 @@ bool Spotify::Track::load()
     return m_loaded;
 }
 
-Spotify::Track* Spotify::Track::fromLink( Spotify::Link& link, QObject* parent )
+Spotify::Track* Spotify::Track::fromLink(sp_session* session, Spotify::Link& link, QObject* parent )
 {
     if( link.isValid() && link.type() == Spotify::Link::TRACK )
     {
         sp_track* track = sp_link_as_track( link.getLink() );
         sp_track_add_ref( track );
         if( track )
-            return new Spotify::Track( track, true, parent );
+            return new Spotify::Track(session, track, true, parent );
     }
     return 0;
 }
